import{r as a}from"./icons.74a49ba5.js";import{d,ey as u,ex as i,a as p,b as _,c as l,e as f,bu as m,bh as y,t as b}from"./registerWidgets.daf4e0d4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1e3c7a9c-8250-4ec7-9c94-9e56841122c3",e._sentryDebugIdIdentifier="sentry-dbid-1e3c7a9c-8250-4ec7-9c94-9e56841122c3")}catch{}})();const v=d({__name:"PreviewButton",props:{model:{}},setup(e){const t=e,o=u(),s=i(),c=()=>{const n=o.query;s.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const r=p("icon");return _(),l("button",{class:"preview-button",onClick:c},[f(r,{class:"icon",path:m(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),y(" Preview ")])}}});const I=b(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.38cc5e26.js.map
