import{L as t}from"./lottie.1c3e1229.js";import{d as a,r,o as d,b as s,c as i,er as c,c2 as _,t as l}from"./registerWidgets.daf4e0d4.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="41a888cf-1382-4f00-8104-2ced24d94a56",n._sentryDebugIdIdentifier="sentry-dbid-41a888cf-1382-4f00-8104-2ced24d94a56")}catch{}})();const u={class:"container"},f=a({__name:"LoadingIndicator",setup(n){const e=r(null);return d(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(s(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const m=l(f,[["__scopeId","data-v-c30401d8"]]);export{m as L};
//# sourceMappingURL=LoadingIndicator.465c522f.js.map
