import{u as s}from"./icons.74a49ba5.js";import{d as c,a as r,b as d,c as i,e as _,bu as l,bh as u,t as b}from"./registerWidgets.daf4e0d4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cd918366-7ea8-4745-8ad4-b12dec0ebeb9",e._sentryDebugIdIdentifier="sentry-dbid-cd918366-7ea8-4745-8ad4-b12dec0ebeb9")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=r("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=f=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=b(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.db58d920.js.map
