import{d as f,ey as b,ex as C,F as _,b as g,u as w,bu as I}from"./registerWidgets.daf4e0d4.js";import{b as h}from"./index.1451144e.js";import"./gateway.c1bf584f.js";import{C as s}from"./connector.ccbfb137.js";import{a as k}from"./asyncComputed.ea0509ca.js";import{f as x,q as D}from"./icons.74a49ba5.js";import{C as E}from"./CrudView.6743e372.js";import"./passwordlessManager.cc6b1127.js";import"./pubsub.bf966380.js";import"./storage.62ab7605.js";import"./activeRecord.8789da8d.js";import"./DropdownMenu.e36b430d.js";import"./Modal.041843ec.js";import"./LoadingIndicator.465c522f.js";import"./lottie.1c3e1229.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="87d8a832-fe9c-4612-a5c5-7521e1913ce4",o._sentryDebugIdIdentifier="sentry-dbid-87d8a832-fe9c-4612-a5c5-7521e1913ce4")}catch{}})();const H=f({__name:"Connectors",setup(o){const n=b(),r=C(),c=n.params.projectId;async function i(e){const t=await s.create(c,e.name,e.type);r.push({name:"connectorEditor",params:{connectorId:t.id}})}const l=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(h.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:p,result:d,refetch:m}=k(()=>s.list(c)),u=_(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"actions"}],rows:(t=(e=d.value)==null?void 0:e.map(a=>({key:a.id,cells:[{text:a.name,classes:["centered"]},{text:a.type},{text:"Actions",classes:["centered"],actions:[{icon:x,label:"Edit",onClick({key:y}){r.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:D,label:"Delete",dangerous:!0,async onClick(){await a.delete(),m()}}]}]})))!=null?t:[]}});return(e,t)=>(g(),w(E,{"entity-name":"connector",loading:I(p),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:l,"create-button-text":"Create connector",onCreate:i},null,8,["loading","table"]))}});export{H as default};
//# sourceMappingURL=Connectors.abfcce40.js.map
